@@ -1,5 +1,6 @@
 from . import ReadData as data
 import numpy as np
+import cmath
 
 def ECAcoustics(atom_IDs,SSFreqFile,ECs,lattice):
 		dim = sum(atom_IDs) * 3
@@ -84,8 +85,8 @@ def ECAcoustics(atom_IDs,SSFreqFile,ECs,lattice):
 			Christoffel_Mat[2,2] = A_3
 			
 			PhaseVelocity = np.linalg.eig(Christoffel_Mat)[0] # = pv^2
-			kzb_vec = np.linalg.norm(kpt_sampling_directions[i,:] * lattice)
-			kzb = (np.pi / (kzb_vec * 1E-10))
+			kzb_vec = np.linalg.norm(np.matmul(kpt_sampling_directions[i,:],lattice))
+			kzb = (1 / (kzb_vec * 1E-10))
 
 			PhaseVelocity = np.transpose(PhaseVelocity)
 			PhaseVelocity = np.sqrt(PhaseVelocity / density)
@@ -93,7 +94,7 @@ def ECAcoustics(atom_IDs,SSFreqFile,ECs,lattice):
 			nan_ind = np.isnan(PhaseVelocity)
 			PhaseVelocity[nan_ind] = 0
 
-			Coeff = 2 * PhaseVelocity * kzb / np.pi
+			Coeff = 2 * PhaseVelocity * kzb 
 			Coeff = Coeff / THz * wvnum
 			Wmax = np.append(Wmax,Coeff)
 
@@ -150,7 +151,7 @@ def ECAcoustics(atom_IDs,SSFreqFile,ECs,lattice):
 		for i in range(TotKpts):
 			x1 = mesh[i,:]
 			dir_id = int(all_ids[i])
-			y = avg_Wmax * abs(np.sin((np.linalg.norm(x1) / np.linalg.norm(kpt_sampling_directions[dir_id,:])) * np.pi / 2))
+			y = avg_Wmax * abs(np.sin((np.linalg.norm(x1) / np.linalg.norm(kpt_sampling_directions[6,:])) * np.pi / 2))
 			DispFreqs = np.append(DispFreqs,y)
 
 		DispFreqs = DispFreqs.reshape([-1,3])
